Pērciet Volkswagen Tiguan 2018 2.0 AWD 110 kW 2018 ar patiesu nobraukumu 102200 km Rīgā oficiālā dīlera salonā
Description: Iegādājaties mazlietotu Pelēks Volkswagen Tiguan ar nobraukumu 102200 km. Mazlietots Volkswagen Tiguan 2018 2.0 AWD 110 kW Automātiskā par 31500 EUR, mazlietotu automobiļu tirdzniecības vietā Inchcape Certified Rīgā.

14
ATLAIDE
3510 €
EUR

Iegādājoties šo auto, DĀVANĀ*:

CSDD Izdevumi
+
OCTA
+
KASKO
VAI
1 GADA GARANTIJA
UZZINĀT VAIRĀK

# Volkswagen Tiguan 2018 2.0 AWD 110 kW, 102200 km

27 990 € 31 500 € (Ieskaitot PVN 21%)
€ 402,35 / mēn.*
Saņemt AutoDNA i
Salons:
Inchcape Certified Skanstes
Skanstes iela 2A
Tālrunis:
+371 (67) 30-3000
Uzzināt vairāk ONLINE konsultācija Pieteikt izmēģinājuma braucienu Sazināties WhatsApp
Izlaiduma gads
2018-03-09
Dzinējs
Dīzeļdegviela
Nobraukums
102 200
Pārnesumkārba
Automātiskā
Piedziņas veids
AWD
Virsbūves tips
SUV
Tehniskie dati
Aprīkojums
Pamatinformācija
Zīmols
Volkswagen
Modelis
Tiguan
Modifikācija
2018 2.0 AWD 110 kW
Nobraukums
102 200
Krāsa
Pelēks
VIN
WVGZZZ5NZJW389548
Izlaiduma gads
2018
Virsbūves tips
SUV
Piedziņas veids
AWD
Pārnesumkārba
Automātiskā
Interjers

- Interjers (Alcantara ādas apdare)
- Interjera krāsa (melna)
- Sēdekļi ar masāžas funkciju
- Regulējams stūres novietojums (augstumā un dziļumā)
- Multistūre
- Apsildāma stūre
- Apsildāmi sēdekļi (priekšējie)
- Priekšējais elkoņbalsts (ar mantu glabātuvi)

Informācijas sistēmas

- Skārienekrāns
- Bluetooth
- Digitāls instrumentu panelis
- Audiosistēma (rūpnīcas)
- LCD ekrāns (priekšā)
- Navigācijas sistēma (ar karti)
- Borta dators
- Radio

Papildus aprīkojums

- Vasaras riepas
- Vieglmetāla diski (18)
- Riepu spiediena kontrole
- Start-stop sistēma
- Āra temperatūras mērītājs
- Otra atslēga (2)
- Pilnpiedziņa 4x4

Drošība

- Stūres pastiprinātājs
- Centrālā atslēga
- ABS pretbloķēšanas sistēma
- Gaisa spilveni (sānu aizkari, atslēdzams pasažiera pusē)
- Elektroniska rokasbremze
- Elektroniskā stabilitātes sistēma (ESP)
- Braukšanas joslu brīdinājuma sistēma
- Braukšanas joslu maiņu asistēšana
- Aklās zonas uzraudzības sistēma
- Ceļa zīmju asistēšana
- Isofix bērnu sēdeklīšu stiprinājumi (aizmugurējos sēdekļos)
- Pretbuksēšanas sistēma (ASR)
- Lietus sensors
- LED lukturi (dienasgaismas, tuvās, tālās, aizmugurējās)
- Priekšējo lukturu apmazgāšana
- Miglas lukturi (priekšējie, aizmugurējie)
- Automātiskās gaismas
- Gaismu aizture aizslēdzot/atslēdzot automobili
- Lasīšanas gaismas

Komforts

- Klimata kontrole (trīszonu)
- Elektriski regulējami sānu spoguļi (apsildāmi, nolokāmi)
- Elektriski atverami/aizverami stikli
- Kruīza kontrole (adaptīvā)
- Elektriski atverams bagāžas nodalījuma vāks (ar tālvadību)
- Autonomā apsilde (dzinēja priekšapsilde, salona priekšapsilde)
- Parkošanās kamera (360 grādu kameras)
- Automātiskā parkošanās sistēma
- Parkošanās sensori (priekšējie, aizmugurejie)
- Salona gaisa filtrs

## Priekšlīzinga kalkulators

Par konkrētu līzinga piedāvājumu interesējieties mūsu salonos

## Operatīvais līzings

€ 207.52 / mēn.

Pirmā iemaksa: 5598 EUR

- 10%
- 20%
- 30%
- 40%
- 50%

Līzinga periods, gadi

- 3
- 4
- 5

Atlikusī vērtība

45%

- 20%
- 25%
- 30%
- 35%
- 40%
- 45%
- 50%

Pieteikties operatīvajam līzingam

## Finanšu līzings

€ 402.35 / mēn.

Pirmā iemaksa: 5598 EUR

- 10%
- 20%
- 30%
- 40%
- 50%

Līzinga periods, gadi

- 3
- 4
- 5

Pieteikties finanšu līzingam

Inchcape Motors Latvia SIA piedāvā finansējumu sadarbībā ar vadošajām līzinga kompānijām.

Aprēķins veikts, ņemot vērā izvēlēta automobiļa cenu finanšuoperatīvajā līzingā ar 20% iemaksu uz 60 mēnešiem ar 45% atlikušo vērtību un 100 000 km limitu.

Procentu likme 3% + EURIBOR (6 mēn.), administrēšanas maksa 1,5%.Aizņemies atbildīgi, izvērtējot savas iespējas atmaksāt

## LĪDZĪGI PIEDĀVĀJUMI

ATLAIDE
1310
EUR
Volvo S90 2.0 FWD 110 kW
29 990 € ar PVN 31 300 €
€ 431 / mēn.*
Izlaiduma gads
2017-04-20
Virsbūves tips
Sedans
Nobraukums
134 000
Piedziņas veids
FWD
Vairāk par auto
ATLAIDE
1600
EUR
Mercedes-Benz A180 1.4
29 900 € bez PVN 31 500 €
€ 430 / mēn.*
Izlaiduma gads
2020-01-20
Virsbūves tips
Hečbeks
Nobraukums
23 490
Piedziņas veids
Vairāk par auto
Volkswagen Touareg 2015 3.0 265hp R-line
31 900 € ar PVN
€ 459 / mēn.*
Izlaiduma gads
2015-10-12
Virsbūves tips
SUV
Nobraukums
91 000
Piedziņas veids
AWD
Vairāk par auto
BMW X3 2.0 AWD 140kw X-line
31 990 € bez PVN
€ 460 / mēn.*
Izlaiduma gads
2018-09-14
Virsbūves tips
SUV
Nobraukums
129 440
Piedziņas veids
AWD
Vairāk par auto
Parādīt visu

## Kāpēc izvēlēties Inchcape Certified?

Padziļināta un kvalitatīva tehniskā pārbaude
Automašīnas tiek pārbaudītas atbilstoši stingriem Inchcape Certified standartiem
Visaptverošs, profesionālu pakalpojumu klāsts
Finansēšana, apdrošināšana, testa braucieni, un citi pakalpojumi pieejami uz vietas
Lietotas automašīnas garantija
6 mēnešu garantija visām Inchcape Certified pārdošanā esošajām automašīnām
Jūsu automašīnas atpirkums (Trade-In)
Jūsu automašīna var kalpot kā pirmā iemaksa
Volkswagen Tiguan 2018 2.0 AWD 110 kW
Pieprasīt zvanu
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Paņem mašīnu

Dīleris

- Inchcape Certified Dārzciema
- Inchcape Certified Skanstes
- Inchcape Certified Ulmaņa

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Apmaiņa

Dīleris

- Inchcape Certified Dārzciema
- Inchcape Certified Skanstes
- Inchcape Certified Ulmaņa

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Novērtējiet

Automašīnas cenas iepriekšēja novērtēšana
Zīmols
No matches found

- AC
- Acura
- Alfa Romeo
- Alpina
- Alpine
- Aro
- Asia
- Aston Martin
- Audi
- Austin
- Autobianchi
- BAIC
- Bentley
- Bertone
- Bitter
- BMW
- Bristol
- Bugatti
- Buick
- BYD
- Cadillac
- Callaway
- Carbodies
- Caterham
- Chery
- Chevrolet
- Chrysler
- Citroen
- Cizeta
- Coggiola
- Dacia
- Dadi
- Daewoo
- Daihatsu
- Daimler
- Datsun
- DeLorean
- De Tomaso
- Derways
- Dodge
- Doninvest
- Donkervoort
- Eagle
- FAW
- Ferrari
- Fiat
- Ford
- FSO
- Geely
- Geo
- GMC
- Great Wall
- Hindustan
- Holden
- Honda
- Hummer
- Hyundai
- Iran Khodro
- Infiniti
- Innocenti
- Invicta
- Isdera
- Isuzu
- JAC
- Jaguar
- Jeep
- Jensen
- Kia
- Koenigsegg
- Lamborghini
- Lancia
- Land Rover
- Landwind
- Lexus
- Lincoln
- Lotus
- LTI
- Mahindra
- Marcos
- Maruti
- Maserati
- Maybach
- Mazda
- McLaren
- Mega
- Mercedes-Benz
- Mercury
- Metrocab
- MG
- Microcar
- Minelli
- MINI
- Mitsubishi
- Mitsuoka
- Morgan
- Morris
- Nissan
- Noble
- Oldsmobile
- Opel
- Osca
- Pagani
- Panoz
- Perodua
- Peugeot
- Plymouth
- Pontiac
- Porsche
- Premier
- Proton
- PUCH
- Puma
- Qvale
- Reliant
- Renault
- Rolls-Royce
- Ronart
- Rover
- Saab
- Saleen
- Renault Samsung
- Saturn
- Scion
- SEAT
- Skoda
- Smart
- Spectre
- Spyker
- SsangYong
- Subaru
- Suzuki
- Talbot
- TATA
- Tatra
- Tianma
- Tianye
- Tofas
- Toyota
- Trabant
- Triumph
- TVR
- Vauxhall
- Vector
- Venturi
- Volkswagen
- Volvo
- Wartburg
- Westfield
- Wiesmann
- Xin Kai
- Zastava
- LADA (ВАЗ)
- ГАЗ
- ЗАЗ
- ЗИЛ
- ИЖ
- ЛуАЗ
- Москвич
- УАЗ
- KTM AG
- Marlin
- PGO
- Piaggio
- Vortex
- Hafei
- Foton
- DongFeng
- Lifan
- ChangFeng
- ShuangHuan
- Brilliance
- Soueast
- ZX
- Fuqi
- HuangHai
- СМЗ
- ТагАЗ
- Gonow
- Baltijas Dzips
- JMC
- Bufori
- Changan
- Liebao Motor
- Tesla
- Marussia
- Haima
- Tazzari
- Ariel
- Santana
- Zotye
- Luxgen
- AM General
- Fisker
- E-Car
- Byvin
- Eagle Cars
- Канонир
- Ё-мобиль
- Tramontana
- Автокам
- Qoros
- Brabus
- Renaissance
- Hawtai
- Ultima
- Gordon
- Haval
- DS
- Jinbei
- Shanghai Maple
- Chana
- Zenvo
- W Motors
- Rezvani
- Rimac
- Adler
- Willys
- DeSoto
- Packard
- Комбат
- Borgward
- Ravon
- ЗиС
- AMC
- Zenos
- Hudson
- Batmobile
- Excalibur
- Genesis
- Wanderer
- Zibar
- Delage
- Steyr
- Hanomag
- Bilenkin
- Think
- Bajaj
- Hispano-Suiza
- GP
- Horch
- Lucid
- DW Hower
- Nash
- Aurus
- Ligier
- Saipa
- Studebaker
- Austin Healey
- GAC
- Спортивные авто и Реплики
- Flanker
- Simca
- Cord
- Changhe
- International
- Rinspeed
- DKW
- IVECO
- Apal
- Logem
- Dallara
- Heinkel
- Yulon
- Sears
- Deco Rides
- Xpeng
- Bio auto
- Roewe
- RAM
- Nio
- LiXiang
- EXEED
- Polestar
- Hennessey
- Auburn
- Weltmeister
- Cupra
- Messerschmitt
- Goggomobil
- Matra
- HSV
- VUHL
- Pierce-Arrow
- Everus
- Ciimo
- Hongqi
- Facel Vega
- Hozon
- Skywell
- Aion
- Blaval
- Voyah

Modelis
No matches found

Izlaiduma gads
No matches found

Virsbūves tips
No matches found

Pārnesumkārba
No matches found

Piedziņas veids

Dzinējs

Krāsa
Stūres novietojuma puse
Kreisā Labā
Kā es varu Jums piezvanīt
Jums ērts zvanu laiks
Dīleris

- Inchcape Certified Dārzciema
- Inchcape Certified Skanstes
- Inchcape Certified Ulmaņa

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Pieteikums AutoDNA atskaites saņemšanai
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

Pieteikums ir pieņemts, paldies

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies

## Pieteikums ONLINE auto apskatei un konsultācijai

Piesakieties automašīnas apskatei un konsultācijai tiešsaistē un gaidiet mūsu pārstāvja zvanu, kura laikā varēsiet vienoties par Jums ērtāko tiešsaistes saziņas kanālu un laiku.

ONLINE saziņas laikā prezentēsim automašīnu, sniegsim ziņas par tās aprīkojumu un tehnisko stāvokli, mūsu pakalpojumiem un finansēšanas iespējām, kā arī atbildes uz visiem Jūsu jautājumiem.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

Pieteikums ir pieņemts, paldies

Cienījamie klienti, vēršam Jūsu uzmanību, ka ievērojot valstī noteikto kārtību, sākot ar 15.11.2021. Inchcape Certified autocentri darbosies epidemioloģiski drošā vidē jeb “zaļajā drošības režīmā”.

Mēs turpinām veikt automašīnu tirdzniecību un servisa pakalpojumu sniegšanu, tomēr ceram uz Jūsu saprati, jo autocentra telpās konsultācijas varēsim sniegt tikai klientiem ar sadarbspējīgu vakcinācijas vai pārslimošanas sertifikātu. Klientus, kuriem nav zaļajam drošības režīmam atbilstoša sertifikāta, apkalposim ārpus autocentra - svaigā gaisā.

Uz tikšanos kādā no Inchcape Certified autocentriem!

PAVASARA PIEDĀVĀJUMS

ĪPAŠAS CENAS UN DĀVANAS MAZLIETOTIEM AUTO

MAZLIETOTI, PROFESIONĀLI PĀRBAUDĪTI AUTO KAS NEPRASA PAPILDUS INVESTĪCIJAS. PĒRC AUTO ŠOBRĪD – MĒS APDROŠINĀSIM UN SEGSIM CSDD IZMAKSAS.

Iegādājies pārbaudītu un uzticamu mazlietotu auto un DĀVANĀ saņem CSDD reģistrācijas izdevumus un OCTA apdrošināšanu, kā arī bonusā papildus izvēlies KASKO vai 1 GADA GARANTIJU.

Šis ir piedāvājums, no kura nav iespējams atteikties.

Apskatīt automašīnu piedāvājumu

*Piedāvājums spēkā līdz no 01.04.2022. līdz 30.04.2022.
**Transportlīdzekļi pieejami tikai vienā eksemplārā.
***Īpašais piedāvājums attiecas tikai uz tām automašīnām, kurām ir pievienotas īpašas dāvanu ikonas mājas lapā. Visām atzīmētajām automašīnām dāvanā sedzam CSDD izdevumus un sniedzam OCTA apdrošināšanu. Automašīnām, kurām ir visas četras dāvanu atzīmes: Jums ir iespēja izvēlēties kā trešo dāvanu KASKO apdrošināšanu vai 1 Gada garantiju.
****OCTA un KASKO polises termiņš atkarīgs no piedāvājuma konkrētam auto..
****Vairāk par 1 gada garantijas nosacījumiem uzziniet šeit.

## Uzzini savas auto līzinga iespējas!

Aizpildi līzinga pieteikuma formu neizejot no mājām, un uzzini par savām iespējām iegādāties auto līzingā.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

Pieteikums ir pieņemts, paldies

## Uzzini savas auto līzinga iespējas!

Aizpildi līzinga pieteikuma formu neizejot no mājām, un uzzini par savām iespējām iegādāties auto līzingā.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

Pieteikums ir pieņemts, paldies

Rezervē savu vizītes laiku!

Piesaki vizīti kādā no trim Inchcape Certified autosaloniem ātri un ērti!

Autocentrs

- Inchcape Certified Ulmaņa
- Inchcape Certified Skanstes
- Inchcape Certified Dārzciema

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

Paldies! Jūsu vizītes pieteikums ir saņemts.

Priecāsimies Jūs redzēt Inchcape Certified - pārbaudītu un uzticamu mazlietotu auto salonā!

NOSKATĪJI AUTO?
PIESAKTIES BEZMAKSAS TESTA BRAUCIENAM!

Piesaki sev interesējošo automobili testa braucienam un mēs parūpēsimies par laicīgu auto sagatavošanu tieši Tev!

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

Paldies! Jūsu pieteikums ir pieņemts.

Priecāsimies Jūs redzēt Inchcape Certified - pārbaudītu un uzticamu mazlietotu auto salonā!

DROSMĪGS PIEDĀVĀJUMS

MAZLIETOTI, PĀRBAUDĪTI AUTO AR NETICAMĀM ATLAIDĒM!

Īpaši piedāvājumi un atlaides vairāk kā 100 000 EUR vērtībā!

Iegādājoties šo transportlīdzekli līdz 20. februārim,

dāvanā sarūpēsim ziemas riepu komplektu!

*Piedāvājums spēkā līdz 28.02.2022.
**Transportlīdzekļi pieejami tikai vienā eksemplārā!
***Atsevišķiem transportlīdzekļiem ziemas riepu komplekts dāvanā. Dāvanas pieejamas tikai tiem transportlīdzekļiem, pie kuriem ir īpašā dāvanas atzīme mājas lapā. Dāvanu skaits ierobežots.

Zīmols

- Audi
- BMW
- BMW Motorrad
- Fiat
- Ford
- Hyundai
- Jaguar
- Kia
- Land Rover
- Lexus
- Mazda
- Mercedes-Benz
- Nissan
- Renault
- Skoda
- Toyota
- Volkswagen
- Volvo

Modelis

Gads no

pirms

Uzlabota meklēšana
121 auto

## Uzlabota meklēšana

Zīmols

- Audi
- BMW
- BMW Motorrad
- Citroen
- Fiat
- Ford
- Honda
- Hyundai
- Jaguar
- Kia
- Land Rover
- Lexus
- Mazda
- Mercedes-Benz
- MINI
- Mitsubishi
- Nissan
- Opel
- Peugeot
- Renault
- SEAT
- Skoda
- Subaru
- Toyota
- Volkswagen
- Volvo

Modelis

Virsbūves tips

- -
- 5 durvis
- Apvidus
- CABRIO
- Cargovan
- Convertible
- Crossover
- GRAND C
- GT
- Hatch (5-door)
- Hečbeks
- KUPEJA
- Kabriolets
- Kravas
- Kupeja
- Limousine
- MOTO
- MOTO SOLO
- MOTOCIKLS SOLO
- MOTOROLLERIS
- Minibus
- Minivans
- Motocikls
- Motocikls solo
- Mtocikls solo
- Pikaps
- SAC
- SAV
- SPORTBACK
- SUV
- Sedans
- Solo
- Sporta tūrisms
- Universālis
- Van
- pickup

ātrumkārba
Automātiskā MANUAL MANUAL DCT Mehāniskā
Ražošanas gads No

- nav svarīgi
- 2022
- 2021
- 2020
- 2019
- 2018
- 2017
- 2016
- 2015
- 2014
- 2013
- 2012
- 2011
- 2010
- 2009
- 2008
- 2007
- 2006
- 2005

Līdz

- nav svarīgi
- 2022
- 2021
- 2020
- 2019
- 2018
- 2017
- 2016
- 2015
- 2014
- 2013
- 2012
- 2011
- 2010
- 2009
- 2008
- 2007
- 2006
- 2005

Dzinēja tilpums no, l

- nav svarīgi

līdz

- nav svarīgi

Krāsa

- Apelsīns
- Balts
- Brūns
- Bēša
- Gaiši pelēks
- Gaiši zils
- Melnais
- Pelēks
- Sarkans
- Sudrabs
- Tumši pelēks
- Tumši sarkans
- Tumši zaļš
- Tumši zils
- Violets
- Zils

Piedziņas veids

- AWD
- FWD
- RWD

Īpašnieku skaits

- Divi īpašnieki
- Nebija īpašniekiem
- Trīs un vairāk īpašnieki

PVN

- ar PVN
- bez PVN

Nodzēst
121 auto

VISS PLUSĀ!

MAZLIETOTI, PROFESIONĀLI PĀRBAUDĪTI AUTO KAS NEPRASA PAPILDUS INVESTĪCIJAS.

MAZLIETOTI, PROFESIONĀLI PĀRBAUDĪTI AUTO KAS NEPRASA PAPILDUS INVESTĪCIJAS. PĒRC AUTO – MĒS APDROŠINĀSIM UN SEGSIM CSDD IZMAKSAS.

Iegādājies šo pārbaudīto un uzticamo mazlietotu auto un DĀVANĀ saņem CSDD reģistrācijas izdevumus, OCTA apdrošināšanu un KASKO.

Iegādājies pārbaudītu un uzticamu mazlietotu auto un DĀVANĀ saņem CSDD reģistrācijas izdevumus un OCTA apdrošināšanu, kā arī bonusā papildus izvēlies KASKO vai 1 GADA GARANTIJU.

Šis ir piedāvājums, no kura nav iespējams atteikties.

Apskatīt automašīnu piedāvājumu

*Piedāvājums spēkā līdz no 01.03.2022. līdz 31.03.2022.
**Transportlīdzekļi pieejami tikai vienā eksemplārā.
***Īpašais piedāvājums attiecas tikai uz tām automašīnām, kurām ir pievienotas īpašas dāvanu ikonas mājas lapā. Visām ar atzīmētajām automašīnām dāvanā sedzam CSDD izdevumus un sniedzam OCTA apdrošināšanu. Automašīnām, kurām ir visas četras dāvanu atzīmes: Jums ir iespēja izvēlēties kā trešo dāvanu KASKO apdrošināšanu vai 1 Gada garantiju.
****OCTA un KASKO polises termiņš atkarīgs no piedāvājuma konkrētam auto.
****Vairāk par 1 gada garantijas nosacījumiem uzziniet šeit.

Meklēt